==> mingw-w64-starpu-1.4.5-2.src.tar.zst: starpu-1.4.5/doc/doxygen_web_introduction/html_web_introduction/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Introduction", "index.html", [
    [ "Introduction", "index.html", [
      [ "we need to keep 2 blank lines above", "index.html#autotoc_md0", null ],
      [ "Motivation", "index.html#Motivation", null ],
      [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
        [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
        [ "StarPU Data Management Library", "index.html#StarPUDataManagementLibrary", null ]
      ] ],
      [ "Application Taskification", "index.html#ApplicationTaskification", null ],
      [ "Research Papers", "index.html#ResearchPapers", null ]
    ] ],
    [ "Glossary", "Glossary.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga3c6c4dd317df02d7021e23ab6b14e3e2",
"group__API__Data__Interfaces.html#ga11d470bd48328eb4432e1c546ea22618",
"group__API__Data__Management.html#ga8b98dee994de7c323a81ac6e573e5693",
"group__API__Initialization__and__Termination.html#a53d18b801302e2ccae6af09c6cdbb2c5",
"group__API__MPI__Support.html#ga6b5f6d7fdf83ed6a9e7d7016cb67ca70",
"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27",
"group__API__Perf__Monitoring.html#ggab66267d03f0557b14cc3ec0c24c01ebaa99c605ec09b32e1cce0ba51df5081f1d",
"group__API__SC__Hypervisor.html#ga035e61bdee7a98948b3c7e2e0b55ef21",
"group__API__Standard__Memory__Library.html#ga864a3b576a56d686010cfd6c9d5ef14b",
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1a59908ef1a8ddbae47f0ff0ed704678af",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__block__filter__block__shadow.html",
"interfacefstarpu__mod_1_1fstarpu__task__get__implementation.html",
"sc__hypervisor__monitoring_8h.html#aeffa224cc0e8e84dcc4decb64f2cb54c"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.8-1.src.tar.zst: starpu-1.4.8/doc/doxygen_web_introduction/html_web_introduction/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Introduction", "index.html", [
    [ "Introduction", "index.html", [
      [ "Motivation", "index.html#Motivation", null ],
      [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
        [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
        [ "StarPU Data Management Library", "index.html#StarPUDataManagementLibrary", null ]
      ] ],
      [ "Application Taskification", "index.html#ApplicationTaskification", null ],
      [ "Research Papers", "index.html#ResearchPapers", null ]
    ] ],
    [ "Glossary", "Glossary.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga35b5e2238449047ac6beb8ef591c6a41",
"group__API__Data__Interfaces.html#ga0b6869745c464525b25a0757d112c318",
"group__API__Data__Management.html#ga8771ea54051655e68ed7a95b4b831fc7",
"group__API__Initialization__and__Termination.html#a401add75734cfd9af675c28424e5977e",
"group__API__MPI__Support.html#ga633d2e3fef4861042eb42e214efa2e43",
"group__API__OpenCL__Extensions.html#gad18d6a0dfbfadcb0fe0b2be6294aa87d",
"group__API__Perf__Monitoring.html#gga1d3b734cccfcb02c47baa5412acf0877a0790e445571b92ba26e67ad4887a4382",
"group__API__SC__Hypervisor.html#ae3a65239bb98f10756743787df0b9319",
"group__API__Standard__Memory__Library.html#ga5a6ea6d03d7b0f4a97a8046b30ecd0bb",
"group__API__Workers.html#gga173d616aefe98c33a47a847fd2fca37dadc9efedf9b6e4e6ce71d8522f6c1206f",
"interfacefstarpu__mod_1_1fstarpu__data__wont__use.html",
"interfacefstarpu__mod_1_1fstarpu__task__end__dep__release.html",
"sc__hypervisor__monitoring_8h.html#acd3f606a760909b7b7262b2927c537b3"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
